summaryrefslogtreecommitdiffhomepage
path: root/packages/browser/src/methods/startAttestation.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/browser/src/methods/startAttestation.ts')
-rw-r--r--packages/browser/src/methods/startAttestation.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/packages/browser/src/methods/startAttestation.ts b/packages/browser/src/methods/startAttestation.ts
index 14ffc53..f77c2de 100644
--- a/packages/browser/src/methods/startAttestation.ts
+++ b/packages/browser/src/methods/startAttestation.ts
@@ -2,7 +2,7 @@ import {
PublicKeyCredentialCreationOptionsJSON,
AuthenticatorAttestationResponseJSON,
AttestationCredential,
-} from '@webauthntine/typescript-types';
+} from '@simplewebauthn/typescript-types';
import toUint8Array from '../helpers/toUint8Array';
import toBase64String from '../helpers/toBase64String';
@@ -12,7 +12,7 @@ import toPublicKeyCredentialDescriptor from '../helpers/toPublicKeyCredentialDes
/**
* Begin authenticator "registration" via WebAuthn attestation
*
* @param creationOptionsJSON Output from @webauthntine/server's generateAttestationOptions(...)
*/
export default async function startAttestation(
creationOptionsJSON: PublicKeyCredentialCreationOptionsJSON,
@@ -12,7 +12,7 @@ import toPublicKeyCredentialDescriptor from '../helpers/toPublicKeyCredentialDes
* Begin authenticator "registration" via WebAuthn attestation
*
- * @param creationOptionsJSON Output from @webauthntine/server's generateAttestationOptions(...)
+ * @param creationOptionsJSON Output from @simplewebauthn/server's generateAttestationOptions(...)
*/
export default async function startAttestation(